@@ -9,14 +9,13 @@ import uuid
 from typing import Optional, Type, Self
 from collections import UserList, UserDict
 
-from .utils import indent_text
 from .sql_section import SqlSection
 from .sql_container import SqlContainer
 from .utils.classes.string_convertible import StringConvertible
 from .utils.classes.container_convertible import ContainerConvertible
 
 
-class SqlQuery(StringConvertible, ContainerConvertible, UserList):
+class SqlQuery(StringConvertible, UserList):
     """SqlQuery is a top-level class for constacting SQL query.
     When you start building query or subquery then you create SqlQuery instance first.
     Second you fill the query out by SQL sections.
@@ -37,6 +36,7 @@ class SqlQuery(StringConvertible, ContainerConvertible, UserList):
         query: Optional[dict] = None,
         *,
         sql_id: Optional[str | uuid.UUID] = '',
+        **sections_default_kwargs,
     ):
         """Create SqlQuery instance.
         Params:
@@ -51,8 +51,12 @@ class SqlQuery(StringConvertible, ContainerConvertible, UserList):
             - sql_id: str - any unique string that will be added at the top of the SQL query
             as comment in format "-- sql_id='your_string_here'". It makes possible to find your
             source code after you encounter query in logs or in debuging tools.
+            - sections_default_kwargs - default kwwargs for all future sections of query such as
+            sep, line_end, section_end, header_ind, body_ind, do_upper_keywords.
         """
         UserList.__init__(self)
+        self.sections_default_kwargs = sections_default_kwargs
+
         self.ctes = SqlCte()
 
         self.sql_id = sql_id or None
@@ -75,15 +79,13 @@ class SqlQuery(StringConvertible, ContainerConvertible, UserList):
             query = SqlQuery()
             query.data = self.data[item]
             return query
-        section = SqlSection(item)
+        section = SqlSection(item, self.sections_default_kwargs)
         self.append(section)
         return section
 
     def __call__(
         self,
         wrap: Optional[str] = None,
-        *,
-        ind: int = 0,  # indentation
     ) -> SqlContainer:
         """Build SQL query by sections.
         Params:
@@ -96,7 +98,7 @@ class SqlQuery(StringConvertible, ContainerConvertible, UserList):
             - ind : int - you could set additional indentation for each line of query text.
             But it is rarely used because nested subelements automatically add 2 space indentation.
         """
-        container = SqlContainer(self.__to_text(ind=ind))
+        container = SqlContainer(self.__to_text())
         if wrap is not None:
             container.wrap(wrap)
 
@@ -130,7 +132,6 @@ class SqlQuery(StringConvertible, ContainerConvertible, UserList):
 
     def __to_text(
         self,
-        ind: int = 0,  # indentation
     ) -> str:
         """
         Used in __call__ method.
@@ -145,7 +146,6 @@ class SqlQuery(StringConvertible, ContainerConvertible, UserList):
 
         sections += [section.container for section in self if section]
         query_text = '\n'.join(str(x) for x in sections) if sections else ''
-        query_text = indent_text.indent_lines(query_text, ind=ind)
         return query_text
 
 
@@ -158,13 +158,27 @@ def add_sections_by_dict(
     """
     Add SqlSections by dict to SqlQuery
     """
-    for section_header, value in data.items():
-        if isinstance(value, (list, tuple)):
-            query[section_header](*value).indent(ind)
+    section_data = dict(data)
+    section_kwargs = query.sections_default_kwargs | {
+        x: kwarg
+        for x in (
+            'header_end',
+            'sep',
+            'line_end',
+            'section_end',
+            'header_ind',
+            'body_ind',
+            'do_upper_keywords',
+        )
+        if (kwarg := section_data.pop('__' + x + '__', None)) is not None
+    }
+    for section_header, value in section_data.items():
+        if isinstance(value, (tuple, list)):
+            query[section_header](*value, **section_kwargs).indent(ind)
         elif isinstance(value, dict):
             add_section_by_dict(query, value, section_header, ind=ind)
         else:
-            query[section_header](value).indent(ind)
+            query[section_header](value, **section_kwargs).indent(ind)
 
 
 def add_section_by_dict(
